Revert "Added canMapHostMemory feature"

This reverts commit af4edd277f.
This commit is contained in:
Aditya Atluri
2016-03-05 13:08:57 -06:00
orang tua af4edd277f
melakukan 2ebbdd6ec5
2 mengubah file dengan 0 tambahan dan 21 penghapusan
-1
Melihat File
@@ -177,7 +177,6 @@ inline static hipError_t hipDeviceGetProperties(hipDeviceProp_t *p_prop, int dev
p_prop->l2CacheSize = cdprop.l2CacheSize ;
p_prop->maxThreadsPerMultiProcessor = cdprop.maxThreadsPerMultiProcessor ;
p_prop->computeMode = cdprop.computeMode ;
p_prop->canMapHostMemory = cdprop.canMapHostMemory;
// Same as clock-rate:
p_prop->clockInstructionRate = cdprop.clockRate;
-20
Melihat File
@@ -1,20 +0,0 @@
#include<iostream>
#include"test_common.h"
__global__ void Add(hipLaunchParm lp, float *Ad, float *Bd, float *Cd){
int tx = hipThreadIdx_x + hipBlockIdx_x * hipBlockDim_x;
Cd[tx] = Ad[tx] + Bd[tx];
}
int main(){
float *A, *B, *C;
float *Ad, *Bd, *Cd;
hipDeviceProp_t prop;
int device;
hipGetDevice(&device);
hipDeviceGetProperties(&prop, device);
if(prop.canMapHostMemory != 1){
std::cout<<"Exiting.."<<std::endl;
}
}